@@ -81,7 +81,7 @@ import java.lang.Character.UnicodeBlock;
  */
 public class TeXFormula {
 
-    public static final String VERSION = "0.9.6";
+    public static final String VERSION = "0.9.7";
 
     public static final int SERIF = 0;
     public static final int SANSSERIF = 1;
@@ -126,10 +126,11 @@ public class TeXFormula {
     public static String[] symbolFormulaMappings = new String[65536];
     public static Map<Character.UnicodeBlock, FontInfos> externalFontMap = new HashMap<Character.UnicodeBlock, FontInfos>();
 
-    public List<MiddleAtom> middle = new LinkedList();
+    public List<MiddleAtom> middle = new LinkedList<MiddleAtom>();
 
+    protected Map<String, String> jlmXMLMap;
     private TeXParser parser;
-
+    
     static {
         // character-to-symbol and character-to-delimiter mappings
         TeXFormulaSettingsParser parser = new TeXFormulaSettingsParser();
@@ -213,6 +214,19 @@ public class TeXFormula {
         parser = new TeXParser("", this, false);
     }
 
+    /**
+     * Creates a new TeXFormula by parsing the given string (using a primitive TeX parser).
+     *
+     * @param s the string to be parsed
+     * @throws ParseException if the string could not be parsed correctly
+     */
+    public TeXFormula(String s, Map<String, String> map) throws ParseException {
+	this.jlmXMLMap = map;
+        this.textStyle = textStyle;
+        parser = new TeXParser(s, this);
+        parser.parse();
+    }
+
     /**
      * Creates a new TeXFormula by parsing the given string (using a primitive TeX parser).
      *
@@ -220,7 +234,7 @@ public class TeXFormula {
      * @throws ParseException if the string could not be parsed correctly
      */
     public TeXFormula(String s) throws ParseException {
-        this(s, null);
+        this(s, (String) null);
     }
 
     public TeXFormula(String s, boolean firstpass) throws ParseException {
@@ -262,8 +276,9 @@ public class TeXFormula {
      * Creates an empty TeXFormula.
      *
      */
-    public TeXFormula(boolean isPartial) {
-        parser = new TeXParser(isPartial, "", this, false);
+    protected TeXFormula(TeXParser tp) {
+	this.jlmXMLMap = tp.formula.jlmXMLMap;
+        parser = new TeXParser(tp.getIsPartial(), "", this, false);
     }
 
     /**
@@ -272,12 +287,14 @@ public class TeXFormula {
      * @param s the string to be parsed
      * @throws ParseException if the string could not be parsed correctly
      */
-    public TeXFormula(boolean isPartial, String s) throws ParseException {
-        this(isPartial, s, null);
+    protected TeXFormula(TeXParser tp, String s) throws ParseException {
+        this(tp, s, null);
     }
 
-    public TeXFormula(boolean isPartial, String s, boolean firstpass) throws ParseException {
+    protected TeXFormula(TeXParser tp, String s, boolean firstpass) throws ParseException {
         this.textStyle = null;
+	this.jlmXMLMap = tp.formula.jlmXMLMap;
+	boolean isPartial = tp.getIsPartial();
         parser = new TeXParser(isPartial, s, this, firstpass);
         if (isPartial) {
             try {
@@ -292,8 +309,10 @@ public class TeXFormula {
      * Creates a TeXFormula by parsing the given string in the given text style.
      * Used when a text style command was found in the parse string.
      */
-    public TeXFormula(boolean isPartial, String s, String textStyle) throws ParseException {
+    protected TeXFormula(TeXParser tp, String s, String textStyle) throws ParseException {
         this.textStyle = textStyle;
+	this.jlmXMLMap = tp.formula.jlmXMLMap;
+	boolean isPartial = tp.getIsPartial();
         parser = new TeXParser(isPartial, s, this);
         if (isPartial) {
             try {
@@ -308,8 +327,10 @@ public class TeXFormula {
         }
     }
 
-    public TeXFormula(boolean isPartial, String s, String textStyle, boolean firstpass, boolean space) throws ParseException {
+    protected TeXFormula(TeXParser tp, String s, String textStyle, boolean firstpass, boolean space) throws ParseException {
         this.textStyle = textStyle;
+	this.jlmXMLMap = tp.formula.jlmXMLMap;
+	boolean isPartial = tp.getIsPartial();
         parser = new TeXParser(isPartial, s, this, firstpass, space);
         if (isPartial) {
             try {
@@ -371,12 +392,13 @@ public class TeXFormula {
     public TeXFormula add(Atom el) {
         if (el != null) {
             if (el instanceof MiddleAtom)
-                middle.add((MiddleAtom)el);
-            if (root == null)
+                middle.add((MiddleAtom) el);
+            if (root == null) {
                 root = el;
-            else {
-                if (!(root instanceof RowAtom))
+            } else {
+                if (!(root instanceof RowAtom)) {
                     root = new RowAtom(root);
+                }
                 ((RowAtom) root).add(el);
             }
         }
@@ -602,6 +624,22 @@ public class TeXFormula {
         TeXEnvironment te = new TeXEnvironment(style, createFont(size, type), widthUnit, textwidth);
         Box box = createBox(te);
         HorizontalBox hb = new HorizontalBox(box, te.getTextwidth(), align);
+
+        TeXIcon ti = new TeXIcon(hb, size, true);
+        ti.isColored = te.isColored;
+        return ti;
+    }
+
+    public TeXIcon createTeXIcon(int style, float size, int widthUnit, float textwidth, int align, int interlineUnit, float interline) {
+        return createTeXIcon(style, size, 0, widthUnit, textwidth, align, interlineUnit, interline);
+    }
+
+    public TeXIcon createTeXIcon(int style, float size, int type, int widthUnit, float textwidth, int align, int interlineUnit, float interline) {
+        TeXEnvironment te = new TeXEnvironment(style, createFont(size, type), widthUnit, textwidth);
+        Box box = createBox(te);
+        float il = interline * SpaceAtom.getFactor(interlineUnit, te);
+        HorizontalBox hb = new HorizontalBox(BreakFormula.split(box, te.getTextwidth(), il), te.getTextwidth(), align);
+
         TeXIcon ti = new TeXIcon(hb, size, true);
         ti.isColored = te.isColored;
         return ti;
@@ -679,7 +717,7 @@ public class TeXFormula {
      * @param size the size
      * @param transparency, if true the background is transparent
      * @return the generated image
-     */ static int toto=0;
+     */
     public Image createBufferedImage(int style, float size, Color fg, Color bg) throws ParseException {
         TeXIcon icon = createTeXIcon(style, size);
         icon.setInsets(new Insets(2, 2, 2, 2));
