@@ -53,6 +53,7 @@ public class TeXParser {
     private boolean arrayMode;
     private boolean ignoreWhiteSpace = true;
     private boolean isPartial;
+    private boolean autoNumberBreaking;
 
     // the escape character
     private static final char ESCAPE = '\\';
@@ -63,6 +64,7 @@ public class TeXParser {
     private static final char L_BRACK = '[';
     private static final char R_BRACK = ']';
     private static final char DOLLAR = '$';
+    private static final char DQUOTE = '\"';
 
     // Percent char for comments
     private static final char PERCENT = '%';
@@ -161,10 +163,10 @@ public class TeXParser {
             this.parseString = new StringBuffer(parseString);
             this.len = parseString.length();
             this.pos = 0;
-            if (firstpass)
+            if (firstpass) {
                 firstpass();
-        }
-        else {
+            }
+        } else {
             this.parseString = null;
             this.pos = 0;
             this.len = 0;
@@ -648,7 +650,7 @@ public class TeXParser {
                             pos++;
                         }
 
-                        formula.add(new MathAtom(new TeXFormula(isPartial, getDollarGroup(DOLLAR), false).root, style));
+                        formula.add(new MathAtom(new TeXFormula(this, getDollarGroup(DOLLAR), false).root, style));
                         if (doubleDollar) {
                             if (parseString.charAt(pos) == DOLLAR) {
                                 pos++;
@@ -660,10 +662,11 @@ public class TeXParser {
                     Atom at = processEscape();
                     formula.add(at);
                     if (arrayMode && at instanceof HlineAtom) {
-                        ((ArrayOfAtoms)formula).addRow();
+                        ((ArrayOfAtoms) formula).addRow();
                     }
-                    if (insertion)
+                    if (insertion) {
                         insertion = false;
+                    }
                     break;
                 case L_GROUP :
                     Atom atom = getArgument();
@@ -676,8 +679,7 @@ public class TeXParser {
                     group--;
                     pos++;
                     if (group == -1)
-                        throw new ParseException("Found a closing '" + R_GROUP
-                                                 + "' without an opening '" + L_GROUP + "'!");
+                        throw new ParseException("Found a closing '" + R_GROUP + "' without an opening '" + L_GROUP + "'!");
                     return;
                 case SUPER_SCRIPT :
                 case SUB_SCRIPT :
@@ -705,6 +707,16 @@ public class TeXParser {
                     }
                     pos++;
                     break;
+                case DQUOTE :
+                    if (ignoreWhiteSpace) {
+                        formula.add(new CumulativeScriptsAtom(getLastAtom(), null, SymbolAtom.get("prime")));
+                        formula.add(new CumulativeScriptsAtom(getLastAtom(), null, SymbolAtom.get("prime")));
+                    } else {
+                        formula.add(convertCharacter(PRIME, true));
+                        formula.add(convertCharacter(PRIME, true));
+                    }
+                    pos++;
+                    break;
                 default :
                     formula.add(convertCharacter(ch, false));
                     pos++;
@@ -953,8 +965,8 @@ public class TeXParser {
         }
 
         Atom at = convertCharacter(ch, true);
-	pos++;
-	return at;
+        pos++;
+        return at;
     }
 
     public String getOverArgument() throws ParseException {
@@ -1015,6 +1027,23 @@ public class TeXParser {
         return str;
     }
 
+    public float[] getLength() throws ParseException {
+        if (pos == len)
+            return null;
+
+        int ogroup = 1, spos;
+        char ch = '\0';
+
+        skipWhiteSpace();
+        spos = pos;
+        while (pos < len && ch != ' ') {
+            ch = parseString.charAt(pos++);
+        }
+        skipWhiteSpace();
+
+        return SpaceAtom.getLength(parseString.substring(spos, pos - 1));
+    }
+
     /** Convert a character in the corresponding atom in using the file TeXFormulaSettings.xml for non-alphanumeric characters
      * @param c the character to be converted
      * @return the corresponding atom
@@ -1039,10 +1068,10 @@ public class TeXParser {
             String symbolName = TeXFormula.symbolMappings[c];
             if (symbolName == null && (TeXFormula.symbolFormulaMappings == null || TeXFormula.symbolFormulaMappings[c] == null)) {
                 TeXFormula.FontInfos fontInfos = TeXFormula.externalFontMap.get(block);
-		if (fontInfos != null) {
-		    if (oneChar) {
-			return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
-		    }
+                if (fontInfos != null) {
+                    if (oneChar) {
+                        return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
+                    }
                     int start = pos++;
                     int end = len - 1;
                     while (pos < len) {
@@ -1083,11 +1112,11 @@ public class TeXParser {
             }
         } else {
             // alphanumeric character
-	    TeXFormula.FontInfos fontInfos = TeXFormula.externalFontMap.get(Character.UnicodeBlock.BASIC_LATIN);
-	    if (fontInfos != null) {
-		if (oneChar) {
-		    return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
-		}
+            TeXFormula.FontInfos fontInfos = TeXFormula.externalFontMap.get(Character.UnicodeBlock.BASIC_LATIN);
+            if (fontInfos != null) {
+                if (oneChar) {
+                    return new JavaFontRenderingAtom(Character.toString(c), fontInfos);
+                }
                 int start = pos++;
                 int end = len - 1;
                 while (pos < len) {
@@ -1222,12 +1251,15 @@ public class TeXParser {
                         args[i] = "" + parseString.charAt(pos);
                         pos++;
                     }
-                    else
+                    else {
                         args[i] = getCommandWithArgs(getCommand());
+                    }
                 }
             }
 
-            skipWhiteSpace();
+            if (ignoreWhiteSpace) {
+                skipWhiteSpace();
+            }
         }
         return args;
     }
